function numOfStableSteps = simulate(theta_init, x_init, g, m_c, m_p, ...
    l, h_max, r_max, tau, simulationTime, k1, k2, k3, k4, bangbang)
    
    % simulation parameters:
    numTimeSteps = simulationTime/tau;
    
    % controller parameters:
    F_m = 100;

    % initial values:
    angle_theta = theta_init;
    angle_velo = 0;
    pos_x = x_init;
    pos_velo = 0;
    if bangbang
        F = F_m; % bang-bang controller
    else
        F = 0;   % continuous force controller
    end

    for t=1:numTimeSteps
        numOfStableSteps = t;
        
        angle_acc = getAngleAccelaration(g, angle_theta, angle_velo, F, m_p, m_c, l);
        pos_acc = getPosAccelaration(F, m_p, l, angle_velo, angle_theta, angle_acc, m_c);

        % integration step of Euler method:
        angle_theta = angle_theta + tau.*angle_velo;
        angle_velo = angle_velo + tau.*angle_acc;
        pos_x = pos_x + tau.*pos_velo;
        pos_velo = pos_velo + tau.*pos_acc;

        % check whether current state is feasible and stop if not:
        if (pos_x < -h_max || pos_x > h_max || ...
                angle_theta < -r_max || angle_theta > r_max)
%            fprintf('Current state of pole not stable after %e seconds\n', t*tau);
%            fprintf('   x_%d = %e; theta_%d = %e\n', t, pos_x, t, angle_theta);
            break;
        end

        % compute response:
        F = linearController(F_m, k1, k2, k3, k4, pos_x, pos_velo, ...
            angle_theta, angle_velo, bangbang);

%        fprintf('iteration %d\n', t);
%        fprintf('---------------\n');
%        fprintf(' x               = %e\n', pos_x);
%        fprintf(' dx/dt           = %e\n', pos_velo);
%        fprintf(' d^2x/dt^2       = %e\n', pos_acc);
%        fprintf(' theta           = %e\n', angle_theta);
%        fprintf(' d(theta)/dt     = %e\n', angle_velo);
%        fprintf(' d^2(theta)/dt^2 = %e\n', angle_acc);
%        fprintf('\n');

    end

end