% model parameters:
theta_init = 0; % initial angle of pole (in radians)
x_init = 0;     % initial cart position (in m)
g = 9.81;       % gravitational acceleration (in m/s^2)
m_c = 1;        % mass of cart (in kg)
m_p = 0.1;      % mass of pole (in kg)
l = 0.5;        % distance from pivot to pole center (length = 2*l)
h_max = 2.4;    % maximal deviation in cart position (in m)
r_max = 0.209;  % maximal deviation in pole angle (in radians=approx. 12)
tau = 0.02;     % time step (in s)

% controller parameters:
bangbang = 1; % set to 0 if you want continuous forces

% simulation parameters:
simulationTime = 120; % (in s)
numOfRandomControllerTests = 1000;

numOfStableControllers = 0;
k1_good = 0;
k2_good = 0;
k3_good = 0;
k4_good = 0;
for i=1:numOfRandomControllerTests;
    % choose controller parameters for linear controller randomly:
    k1 = rand(1);
    k2 = rand(1);
    k3 = rand(1);
    k4 = rand(1);
    
    numOfStableSteps = simulate(theta_init, x_init, g, m_c, m_p, l, ...
        h_max, r_max, tau, simulationTime, k1, k2, k3, k4, bangbang);
    
    fprintf('run %d: %d number of stable simulation steps\n', i, numOfStableSteps);
    if numOfStableSteps == simulationTime/tau
        fprintf(' k1=%e, k2=%e, k3=%e, k4=%e\n', k1, k2, k3, k4);
        numOfStableControllers = numOfStableControllers + 1;
        k1_good = k1;
        k2_good = k2;
        k3_good = k3;
        k4_good = k4;
    end
end

fprintf('Total number of stable controllers: %d/%d\n', ...
    numOfStableControllers, numOfRandomControllerTests);
fprintf('Last stable values for controller: k1=%e, k2=%e, k3=%e, k4=%e\n', ...
    k1_good, k2_good, k3_good, k4_good);




